#!/bin/sh 
# define HISTFILE0; final assembled hist file (binary)
#        HISTFILET; temporary  hist file
HISTFILE0=./$EXECID.hist
export HISTFILE0
HISTFILET=./temp.hist
export HISTFILET


